<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-plan?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// P
	'plan_description' => 'このプラグインは、折りたたみ可能な構造を表示し、記事のステータスでソートすることによって、管理エリアのページ「サイトマップ」を改善します。',
	'plan_nom' => '管理エリアのサイトマップ',
	'plan_slogan' => '管理エリアのサイトマップを改善する。',
];
